function [adj,adjn] = Random_Geometric(nnodes,dim)
% Create Random Geometric graph with edge weights inversly proportional to
% distance between vectors i,j chosen uniformly at random in [0,1]^dim.
% Kahle, M. (2011)  Random geometric complexes. Discrete & Computational
%  Geometry,45(3), 553--573.

% Inputs
    % nnodes = number of nodes for network
    % dim = dimension of vectors
    
% Outputs
    % adj = adjacency matrix with A_ij = 1/d(i,j) where d(i,j) is the
    % euclidean distance
    % adjn = adj since no noise needed
% Reference: Ann Sizemore, Chad Giusti and Danielle S. Bassett,
% Classification of weighted networks through mesoscale homological 
% features (arXiv:1512.06457 [math.CO]) (submitted)

    
coords = rand(nnodes,dim);        % Choose random points

D = pdist(coords);              % Calculate Euclidean distance
D = squareform(D);              % Rewrite distances into distance matrix D

adj = 1./D;                     % Order adjacency matrix by distance 
                                % giving closest points highest weight
adj(isinf(adj)) = 0;
adjn = adj;


end

