function [adj,adjn] = Watts_Strogatz(nnodes,k,p)
% Create a Watts-Strogatz small world network with each node wired to 
% k nearest neighbors.
%Watts, D.~J. & Strogatz, S.~H. (1998)  Collective dynamics of
%  small-worldnetworks. nature,393(6684), 440--442
%
% For the classification of weighted networks, maximized small world
% propensity (Muldoon, S.~F., Bridgeford, E.~W. & Bassett, D.~S. (2015)  Small-World
% Propensity in Weighted, Real-World Networks. arXiv preprint
%	arXiv:1505.02194).

% Inputs
    % nnodes = number of nodes
    % k = desired degree for each node (needs to be even). 
    % p = probability of edge switching
    
% Outputs
    % adj = adjacency matrix after edge switching procedure.
    % adjn = adj + noise to ensure edge uniqueness.

% Reference: Ann Sizemore, Chad Giusti and Danielle S. Bassett,
% Classification of weighted networks through mesoscale homological 
% features (arXiv:1512.06457 [math.CO]) (submitted)
    
    
adj = zeros(nnodes,nnodes);


% Wire

for i = 1:nnodes
    for j= i+1:i+(k/2)
        
                
        if j> nnodes
            j1 = j - nnodes;
        adj(i,j1) = 1/(j-i);
        adj(j1,i) = adj(i,j1);
        end
        
        if j<=nnodes
        adj(i,j) = 1/(j-i);
        adj(j,i) = adj(i,j);
        end
        
    end
end


%% Rewire with probability p

edgerewire = 0;         % Use this to keep track of the number of edges 
                        % rewired, if desired.

for i = 1:nnodes
    for j= i+1:i+(k/2)
        
                
        if j> nnodes
            j1 = j - nnodes;
        
            if adj(i,j1) > 0 
            r = rand;
                if r < p            % Rewire

                    ind = find(adj(i,:) == 0); 
                    ind(ind==i) = [];
                    l = length(ind);
                    if l > 0
                        
               a = randperm(l,1); % Choose a random node not connected
                           
               adj(i,ind(a)) = adj(i,j1);       %Rewire
               adj(ind(a),i) = adj(i,j1);
               adj(i,j1) = 0;
               adj(j1,i) = 0; 
               edgerewire = edgerewire+1;
                    end 

               end
            end
        
        end
        
        if j<=nnodes
        
            if adj(i,j) > 0 
            r = rand;
                if r < p

                     ind = find(adj(i,:) == 0); 
                    ind(ind==i) = [];
                    l = length(ind);
                    if l > 0
                        
               a = randperm(l,1); % Choose a random node not connected
                           
               adj(i,ind(a)) = adj(i,j);        % Rewire
               adj(ind(a),i) = adj(i,j);
               adj(i,j) = 0;
               adj(j,i) = 0; 
               edgerewire = edgerewire+1;
                    end 

               end
            end
        end
    end
end



 %% Add noise
 
 adjn = adj;
for i = 1:nnodes
    for j = i+1:nnodes
        
        r = 0.001*rand;
        
        while r<0
            r = 0.001*rand;
        end
        adjn(i,j) = adjn(i,j) + r;
        adjn(j,i) = adjn(i,j);
        
    end
end




end

