%% For ATiNS example for multiple edge weighted networks
% 03.20.18

% Prepare environment
clear
close all

% Set parameters
filename = 'CCG';
filename1 = sprintf('fromJulia_%s',filename);
nReps = 1;
nNodes = 78;
isOcf = 1;
exMat = 14;          % Example matrix to use for barcodes, PDs
del = 0;
nEdges = nchoosek(nNodes,2);
labels = 1:nEdges;
confidence = 0.95;
lineColor = (1/255)*[21 50 78; 55 120 120; 107 158 105];
colors = lineColor;
intervalColor = lineColor + 0.15;
maxDim = 3;


% Convert the julia files to a cell of persistence intervals. If del=1, the
% individual rep files from julia will be deleted.
%allPIs = juliaToPIs( filename1, nReps, del);

load(sprintf('%s_pis.mat',filename1))
allPIs = allPersistenceIntervals;

% To make betti curves, transform perisstence intervals

[ bettis ] = allPIsToBettis(allPIs,nEdges);

 
%% Draw average betti curves
% "Standard" colors are dim 1 = blue, dim 2 = green, dim 3 = red.

figure('Color',[1 1 1])
[ ~, bettiCurvesAvg] = plotBettiCurves_J(allPIs,maxDim, nNodes);
hold on
axis([0 1 0 inf])
title('Betti Curves')




%% Draw Betti Curves with error
% We will use our own colors now

figure('Color',[1 1 1])
draw_betti_curves_with_error_outline(bettis,labels, confidence, ...
    lineColor, intervalColor, '-',1.7,nEdges,1500);
set(gcf,'Position',[0 0 550 2000])
box on                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            
ax = gca;
ax.LineWidth = 1.7;



%% Draw barcodes - from one example matrix

next = 1;
figure('Color',[1 1 1])
for dim1 = 1:3
    [ barcodes,next1 ] = plotBarcode(allPIs{exMat}{dim1}, nEdges, dim1,...
        'none', next,1,colors);
    hold on
    next = next + next1 + 1;
end

axis([0 nEdges 0 (next+5)])
ax = gca;
ax.XTick = [];
xlabel('Filtration value')




%% Draw the persistence diagram - from one example matrix

alpha = 0.2;
plotPersistenceDiagram(allPIs{exMat},maxDim,nEdges,colors,alpha)
