function [ adj,adjn ] = iid(nnodes)
% Construct a graph where entries are chosen from a uniform distribution

% Kahle, M. (2011)  Random geometric complexes. {\em DCG}, \textbf{45}(3),
% 553--573.

% Inputs
    % nnodes = number of nodes
    
% Outputs
    % adj = final nnodesxnnodes adjacency matrix with entries chosen from
    % uniform distribution
    % adjn = adj since all adj edge weights are already unique.

% Reference: Ann Sizemore, Chad Giusti and Danielle S. Bassett,
% Classification of weighted networks through mesoscale homological 
% features (arXiv:1512.06457 [math.CO]) (submitted)
    
% Choose edge weights
adj = rand(nnodes,nnodes);
    for i = 1:nnodes;
    for j = i:nnodes
        adj(i,j) = adj(j,i);            % Make matrix symmetric
        if i==j
            adj(i,j) = 0;               % Ensure diagonals are 0
        end
    end
    end
    
    % No noise needed since edge weights are unique
    adjn = adj;
end

